| Title: | GPL Palettes Copied from 'Gimp' and 'Inkscape' |
|---|---|
| Description: | A set of palettes imported from 'Gimp' distributed under GPL3 (<https://www.gimp.org/about/COPYING>), and 'Inkscape' distributed under GPL2 (<https://inkscape.org/about/license/>). |
| Authors: | Francois Rebaudo [aut, cre], Gimp [cph] (copyright holder for palettes imported from Gimp), Inkscape [cph] (copyright holder for palettes imported from Inkscape) |
| Maintainer: | Francois Rebaudo <[email protected]> |
| License: | GPL-2 |
| Version: | 0.1.2 |
| Built: | 2026-05-22 06:49:31 UTC |
| Source: | https://github.com/frareb/palettesforr |
A palette in hexadecimal format extracted from the Gimp or Inkscape.
Android_gplAndroid_gpl
A vector of length 15
A palette in hexadecimal format extracted from the Gimp or Inkscape.
Bears_gplBears_gpl
A vector of length 256
A palette in hexadecimal format extracted from the Gimp or Inkscape.
Bgold_gplBgold_gpl
A vector of length 256
A palette in hexadecimal format extracted from the Gimp or Inkscape.
Blues_gplBlues_gpl
A vector of length 256
A palette in hexadecimal format extracted from the Gimp or Inkscape.
Borders_gplBorders_gpl
A vector of length 256
A palette in hexadecimal format extracted from the Gimp or Inkscape.
Browns_gplBrowns_gpl
A vector of length 22
A palette in hexadecimal format extracted from the Gimp or Inkscape.
Caramel_gplCaramel_gpl
A vector of length 256
A palette in hexadecimal format extracted from the Gimp or Inkscape.
Cascade_gplCascade_gpl
A vector of length 256
A palette in hexadecimal format extracted from the Gimp or Inkscape.
China_gplChina_gpl
A vector of length 256
A palette in hexadecimal format extracted from the Gimp or Inkscape.
Coldfire_gplColdfire_gpl
A vector of length 256
A palette in hexadecimal format extracted from the Gimp or Inkscape.
Cool_gplCool_gpl
A vector of length 8
A palette in hexadecimal format extracted from the Gimp or Inkscape.
Cranes_gplCranes_gpl
A vector of length 256
A palette in hexadecimal format extracted from the Gimp or Inkscape.
Dark_gplDark_gpl
A vector of length 256
A palette in hexadecimal format extracted from the Gimp or Inkscape.
Default_gplDefault_gpl
A vector of length 23
A palette in hexadecimal format extracted from the Gimp or Inkscape.
Echo_gplEcho_gpl
A vector of length 27
A palette in hexadecimal format extracted from the Gimp or Inkscape.
Ega_gplEga_gpl
A vector of length 240
A palette in hexadecimal format extracted from the Gimp or Inkscape.
Firecode_gplFirecode_gpl
A vector of length 256
A palette in hexadecimal format extracted from the Gimp or Inkscape.
Gold_gplGold_gpl
A vector of length 102
A palette in hexadecimal format extracted from the Gimp or Inkscape.
Gray_gplGray_gpl
A vector of length 256
A palette in hexadecimal format extracted from the Gimp or Inkscape.
Grayblue_gplGrayblue_gpl
A vector of length 256
A palette in hexadecimal format extracted from the Gimp or Inkscape.
Grays_gplGrays_gpl
A vector of length 31
A palette in hexadecimal format extracted from the Gimp or Inkscape.
GrayViolet_gplGrayViolet_gpl
A vector of length 256
A palette in hexadecimal format extracted from the Gimp or Inkscape.
Greens_gplGreens_gpl
A vector of length 256
A palette in hexadecimal format extracted from the Gimp or Inkscape.
Hilite_gplHilite_gpl
A vector of length 170
A palette in hexadecimal format extracted from the Gimp or Inkscape.
Inkscape_gplInkscape_gpl
A vector of length 431
A palette in hexadecimal format extracted from the Gimp or Inkscape.
Khaki_gplKhaki_gpl
A vector of length 156
A palette in hexadecimal format extracted from the Gimp or Inkscape.
LaTeX_gplLaTeX_gpl
A vector of length 136
A palette in hexadecimal format extracted from the Gimp or Inkscape.
Lights_gplLights_gpl
A vector of length 25
A palette in hexadecimal format extracted from the Gimp or Inkscape.
MATLAB_gplMATLAB_gpl
A vector of length 73
A palette in hexadecimal format extracted from the Gimp or Inkscape.
Muted_gplMuted_gpl
A vector of length 78
A palette in hexadecimal format extracted from the Gimp or Inkscape.
Named_gplNamed_gpl
A vector of length 448
A palette in hexadecimal format extracted from the Gimp or Inkscape.
News3_gplNews3_gpl
A vector of length 256
A palette in hexadecimal format extracted from the Gimp or Inkscape.
Op2_gplOp2_gpl
A vector of length 256
A palette in hexadecimal format extracted from the Gimp or Inkscape.
Paintjet_gplPaintjet_gpl
A vector of length 16
A palette in hexadecimal format extracted from the Gimp or Inkscape.
Pastels_gplPastels_gpl
A vector of length 18
A palette in hexadecimal format extracted from the Gimp or Inkscape.
Plasma_gplPlasma_gpl
A vector of length 256
A palette in hexadecimal format extracted from the Gimp or Inkscape.
Reds_gplReds_gpl
A vector of length 177
A palette in hexadecimal format extracted from the Gimp or Inkscape.
Royal_gplRoyal_gpl
A vector of length 222
Show a palette.
showPalette(myPal)showPalette(myPal)
myPal |
The palette name. |
Adapted from http://www.r-graph-gallery.com/42-colors-names/
data(Caramel_gpl) showPalette(myPal = Caramel_gpl)data(Caramel_gpl) showPalette(myPal = Caramel_gpl)
A palette in hexadecimal format extracted from the Gimp or Inkscape.
SVG_gplSVG_gpl
A vector of length 139
A palette in hexadecimal format extracted from the Gimp or Inkscape.
Tango_gplTango_gpl
A vector of length 29
A palette in hexadecimal format extracted from the Gimp or Inkscape.
Topographic_gplTopographic_gpl
A vector of length 191
A palette in hexadecimal format extracted from the Gimp or Inkscape.
Visibone_gplVisibone_gpl
A vector of length 336
A palette in hexadecimal format extracted from the Gimp or Inkscape.
Volcano_gplVolcano_gpl
A vector of length 256
A palette in hexadecimal format extracted from the Gimp or Inkscape.
Warm_gplWarm_gpl
A vector of length 7
A palette in hexadecimal format extracted from the Gimp or Inkscape.
Web_gplWeb_gpl
A vector of length 216
A palette in hexadecimal format extracted from the Gimp or Inkscape.
WebHex_gplWebHex_gpl
A vector of length 216
A palette in hexadecimal format extracted from the Gimp or Inkscape.
WebSafe22_gplWebSafe22_gpl
A vector of length 22
A palette in hexadecimal format extracted from the Gimp or Inkscape.
Windows_gplWindows_gpl
A vector of length 31